<?php
/*********************************************************************************
 * TimeTrex is a Payroll and Time Management program developed by
 * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License along
 * with this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 *
 * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
 * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by TimeTrex".
 ********************************************************************************/
/*
 * $Revision: 4207 $
 * $Id: UserRequestList.php 4207 2011-02-02 00:54:08Z ipso $
 * $Date: 2011-02-01 16:54:08 -0800 (Tue, 01 Feb 2011) $
 */
require_once('../../includes/global.inc.php');
require_once(Environment::getBasePath() .'includes/Interface.inc.php');

if ( !$permission->Check('request','enabled')
		OR !( $permission->Check('request','view') OR $permission->Check('request','view_own') OR $permission->Check('request','view_child') ) ) {
	$permission->Redirect( FALSE ); //Redirect
}

$smarty->assign('title', TTi18n::gettext($title = 'Request List')); // See index.php
BreadCrumb::setCrumb($title);

/*
 * Get FORM variables
 */
extract	(FormVariables::GetVariables(
										array	(
												'action',
												'page',
												'sort_column',
												'sort_order',
												'filter_user_id',
												'filter_start_date',
												'filter_end_date',
												'ids',
												) ) );

URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
											array(
													'filter_user_id' => $filter_user_id,
													'filter_start_date' => $filter_start_date,
													'filter_end_date' => $filter_end_date,
													'sort_column' => $sort_column,
													'sort_order' => $sort_order,
													'page' => $page
												) );

$sort_array = NULL;
if ( $sort_column != '' ) {
	$sort_array = array($sort_column => $sort_order);
}

$filter_data = array();
//Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
$permission_children_ids = array();
if ( $permission->Check('request','view') == FALSE ) {
	$hlf = TTnew( 'HierarchyListFactory' );
	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );

	if ( $permission->Check('request','view_child') == FALSE ) {
		$permission_children_ids = array();
	}
	if ( $permission->Check('request','view_own') ) {
		$permission_children_ids[] = $current_user->getId();
	}

	$filter_data['permission_children_ids'] = $permission_children_ids;
}

Debug::Arr($ids,'Selected Objects', __FILE__, __LINE__, __METHOD__,10);

$action = Misc::findSubmitButton();
switch ($action) {
	case 'add':
		//Should have a pop-up
		//Redirect::Page( URLBuilder::getURL( NULL, 'EditRequest.php', FALSE) );

		break;
	case 'delete':
	case 'undelete':
		//Debug::setVerbosity(11);
		if ( strtolower($action) == 'delete' ) {
			$delete = TRUE;
		} else {
			$delete = FALSE;
		}

		$rlf = TTnew( 'RequestListFactory' );

		foreach ($ids as $id) {
			$rlf->getByIdAndCompanyId( $id, $current_company->getId() );
			foreach ($rlf as $r_obj) {
				$r_obj->setDeleted($delete);
				$r_obj->Save();
			}
		}

		Redirect::Page( URLBuilder::getURL( array( 'filter_user_id' => $filter_user_id ), 'UserRequestList.php') );

		break;

	default:
		if ( !isset($filter_user_id) ) {
			$filter_user_id = $user_id = $current_user->getId();
		}

		if ( isset($filter_user_id) ) {
			$filter_data['user_id'] = $filter_user_id;
		}

		if ( isset($filter_start_date) AND $filter_start_date != '' AND isset($filter_end_date) AND $filter_end_date != '') {
			$filter_data['start_date'] = $filter_start_date;
			$filter_data['end_date'] = $filter_end_date;
		}

		$rlf = TTnew( 'RequestListFactory' );
		$rlf->getByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data, $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );

		/*
		if ( isset($filter_start_date) AND $filter_start_date != '' AND isset($filter_end_date) AND $filter_end_date != '') {
			$rlf->getByUserIdAndCompanyIdAndStartDateAndEndDate( $user_id, $current_company->getId(), $filter_start_date, $filter_end_date, $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
		} else {
			$rlf->getByUserIDAndCompanyId( $user_id, $current_company->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
		}
		*/

		$pager = new Pager($rlf);

		$status_options = $rlf->getOptions('status');
		$type_options = $rlf->getOptions('type');

		foreach ($rlf as $r_obj) {
			Debug::Text('Status ID: '. $r_obj->getStatus() .' Status: '. $status_options[$r_obj->getStatus()], __FILE__, __LINE__, __METHOD__,10);
			$requests[] = array(
								'id' => $r_obj->getId(),
								'user_date_id' => $r_obj->getUserDateID(),
								'date_stamp' => TTDate::strtotime($r_obj->getColumn('date_stamp')),
								'status_id' => $r_obj->getStatus(),
								'status' => $status_options[$r_obj->getStatus()],
								'type_id' => $r_obj->getType(),
								'type' => $type_options[$r_obj->getType()],
								'created_date' => $r_obj->getCreatedDate(),
								'deleted' => $r_obj->getDeleted()
							);

		}

		$ulf = TTnew( 'UserListFactory' );
		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
		$user_options = UserListFactory::getArrayByListFactory( $ulf, FALSE, FALSE );

		$smarty->assign_by_ref('user_options', $user_options);
		$smarty->assign_by_ref('requests', $requests);

		$smarty->assign_by_ref('filter_user_id', $filter_user_id);

		$smarty->assign_by_ref('sort_column', $sort_column );
		$smarty->assign_by_ref('sort_order', $sort_order );

		$smarty->assign_by_ref('paging_data', $pager->getPageVariables() );

		break;
}
$smarty->display('request/UserRequestList.tpl');
?>